@@ -13,9 +13,11 @@ from las.credentials import MissingCredentials, read_from_file
 
 from .util import NotProvided
 from .parser import (
-    create_assets_parser, create_batches_parser, create_documents_parser,
-    create_models_parser, create_predictions_parser, create_secrets_parser,
-    create_transitions_parser, create_users_parser, create_workflows_parser,
+    create_assets_parser, create_batches_parser,
+    create_documents_parser, create_logs_parser,
+    create_models_parser, create_predictions_parser,
+    create_secrets_parser, create_transitions_parser,
+    create_users_parser, create_workflows_parser,
 )
 
 
@@ -28,6 +30,7 @@ def create_parser():
     create_assets_parser(subparsers)
     create_batches_parser(subparsers)
     create_documents_parser(subparsers)
+    create_logs_parser(subparsers)
     create_models_parser(subparsers)
     create_predictions_parser(subparsers)
     create_secrets_parser(subparsers)
@@ -66,7 +69,9 @@ def main():
 
     kwargs = {k: v for k, v in args.items() if v != NotProvided}
     if kwargs:
-        print(json.dumps(cmd(**kwargs), indent=2))
+        result = cmd(**kwargs)
+        result = json.dumps(result, indent=2) if isinstance(result, dict) else result
+        print(result)
     else:
         parser.print_help()
 
