@@ -1,8 +1,8 @@
 from las import Client
 
 
-def post_predictions(las_client: Client, document_id, model_id):
-    return las_client.create_prediction(document_id, model_id)
+def post_predictions(las_client: Client, document_id, model_id, auto_rotate, max_pages):
+    return las_client.create_prediction(document_id, model_id, auto_rotate=auto_rotate, max_pages=max_pages)
 
 
 def list_predictions(las_client: Client, max_results=None, next_token=None):
@@ -16,6 +16,8 @@ def create_predictions_parser(subparsers):
     create_predicton_parser = subparsers.add_parser('create')
     create_predicton_parser.add_argument('document_id')
     create_predicton_parser.add_argument('model_id')
+    create_predicton_parser.add_argument('--auto-rotate', action='store_true', default=False)
+    create_predicton_parser.add_argument('--max-pages', type=int, default=1)
     create_predicton_parser.set_defaults(cmd=post_predictions)
 
     list_predictions_parser = subparsers.add_parser('list')
