@@ -11,17 +11,17 @@ def create_transition(
     transition_type,
     in_schema_path=None,
     out_schema_path=None,
-    params_path=None,
+    parameters_path=None,
     **optional_args,
 ):
     in_schema = json.loads(pathlib.Path(in_schema_path).read_text()) if in_schema_path else None
     out_schema = json.loads(pathlib.Path(out_schema_path).read_text()) if out_schema_path else None
-    params = json.loads(pathlib.Path(params_path).read_text()) if params_path else None
+    parameters = json.loads(pathlib.Path(parameters_path).read_text()) if parameters_path else None
     return las_client.create_transition(
         transition_type,
         in_schema=in_schema,
         out_schema=out_schema,
-        params=params,
+        parameters=parameters,
         **optional_args
     )
 
@@ -44,6 +44,10 @@ def list_transition_executions(las_client: Client, transition_id, **optional_arg
     return las_client.list_transition_executions(transition_id, **optional_args)
 
 
+def get_transition_execution(las_client: Client, transition_id, execution_id):
+    return las_client.get_transition_execution(transition_id, execution_id)
+
+
 def update_transition_execution(
     las_client: Client,
     transition_id,
@@ -69,7 +73,7 @@ def create_transitions_parser(subparsers):
 
     create_parser = subparsers.add_parser('create')
     create_parser.add_argument('transition_type', choices=["docker", "manual"])
-    create_parser.add_argument('--params-path', '-p', help='parameters to the docker image')
+    create_parser.add_argument('--parameters-path', '-p', help='parameters to the docker image')
     create_parser.add_argument('--in-schema-path')
     create_parser.add_argument('--out-schema-path')
     create_parser.add_argument('--name', type=nullable, default=NotProvided)
@@ -104,6 +108,11 @@ def create_transitions_parser(subparsers):
     list_executions_parser.add_argument('--next-token', '-n', type=str)
     list_executions_parser.set_defaults(cmd=list_transition_executions)
 
+    get_execution_parser = subparsers.add_parser('get-execution')
+    get_execution_parser.add_argument('transition_id')
+    get_execution_parser.add_argument('execution_id')
+    get_execution_parser.set_defaults(cmd=get_transition_execution)
+
     update_execution_parser = subparsers.add_parser('update-execution')
     update_execution_parser.add_argument('transition_id')
     update_execution_parser.add_argument('execution_id')
